Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(216)

Unified Diff: sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart

Issue 899373002: Update pub to use the VM's new bad-snapshot exit code. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fix status and one more test Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart
diff --git a/sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart b/sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart
index 1d612a1b6162a8d6523aa8b8bc274dab54b246ea..e84f4e8cd16c7e48823c0653713bbf01f8afe057 100644
--- a/sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart
+++ b/sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart
@@ -57,8 +57,8 @@ main() {
// The broken versions should have been replaced.
d.dir(cachePath, [
d.dir('bin', [
- // 255 is the VM's exit code upon seeing an out-of-date snapshot.
- d.matcherFile(binStubName('foo-script'), contains('255'))
+ // 253 is the VM's exit code upon seeing an out-of-date snapshot.
+ d.matcherFile(binStubName('foo-script'), contains('253'))
])
]).validate();
});
« no previous file with comments | « sdk/lib/_internal/pub/pub.status ('k') | sdk/lib/_internal/pub/test/global/activate/outdated_binstub_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698